@@ -30,7 +30,7 @@ class MAILIMPORTER_EXPORT FilterKMail_maildir : public Filter
 {
 public:
     FilterKMail_maildir();
-    ~FilterKMail_maildir();
+    ~FilterKMail_maildir() override;
 
     void import() override;
     void importMails(const QString &maildir);
